@@ -143,7 +143,7 @@ class SchemaClient:
                 lambda _: self.create(schema)
             )
             if b
-            else Cmd.from_cmd(lambda: None)
+            else self.create(schema)
         )
 
     def recreate(self, schema: SchemaId) -> Cmd[None]:
