@@ -95,6 +95,9 @@ class SqlClient:
 
     def values(self, query: Query, args: PureIter[RowData]) -> Cmd[None]:
         def _action() -> None:
+            self._log.debug(
+                "Executing query over values: %s", query._inner.statement
+            )
             _args = args.map(lambda r: r.data)
             extras.execute_values(self._cursor, query._inner.statement, _args)
 
@@ -102,6 +105,7 @@ class SqlClient:
 
     def fetch_one(self) -> Cmd[Maybe[RowData]]:
         def _action() -> Maybe[RowData]:
+            self._log.debug("Fetching one row")
             return Maybe.from_optional(
                 _assert.assert_fetch_one(self._cursor.fetchone())  # type: ignore[misc]
             ).map(RowData)
@@ -110,6 +114,7 @@ class SqlClient:
 
     def fetch_all(self) -> Cmd[FrozenList[RowData]]:
         def _action() -> FrozenList[RowData]:
+            self._log.debug("Fetching all rows")
             items = _assert.assert_fetch_list(tuple(self._cursor.fetchall()))  # type: ignore[misc]
             return tuple(map(RowData, items))
 
@@ -117,6 +122,7 @@ class SqlClient:
 
     def fetch_many(self, chunk: int) -> Cmd[FrozenList[RowData]]:
         def _action() -> FrozenList[RowData]:
+            self._log.debug("Fetching %s rows", chunk)
             items = _assert.assert_fetch_list(tuple(self._cursor.fetchmany(chunk)))  # type: ignore[misc]
             return tuple(map(RowData, items))
 
