@@ -38,6 +38,11 @@ def new(
     primary_keys: FrozenSet[ColumnId],
 ) -> ResultE[Table]:
     in_columns: Callable[[ColumnId], bool] = lambda k: k in columns
+    non_duplicated = len(frozenset(order)) == len(order)
+    if not non_duplicated:
+        return Result.failure(
+            Exception("order list must have unique `ColumnId` objs")
+        )
     if all(map(in_columns, primary_keys)):
         draft = _Table(order, columns, primary_keys)
         return Result.success(Table(draft))
